@@ -50,9 +50,8 @@ __license__ = "GPLv2"
 __maintainer__ = "Michael G. Noll"
 __status__ = "Development"
 __url__ = "http://www.michael-noll.com/"
-__version__ = "1.6.4"
+__version__ = "1.6.5"
 
-import base64
 import cgi
 import datetime
 import hashlib
@@ -61,7 +60,6 @@ import re
 import socket
 import time
 import urllib2
-import xml.dom.minidom
 
 try:
     from BeautifulSoup import BeautifulSoup
@@ -767,9 +765,9 @@ class DeliciousAPI(object):
             user_tags = []
             tagdisplays = bookmark_element.findAll("div", attrs={"class": "tagdisplay"})
             if tagdisplays:
-                spans = tagdisplays[0].findAll("span", attrs={"class": "tagItem"})
-                for span in spans:
-                    tag = span.contents[0]
+                aset  = tagdisplays[0].findAll("a", attrs={"class": "tagItem noplay"})
+                for a in aset:
+                    tag = a.contents[0]
                     user_tags.append(tag)
 
             # extract user information
@@ -843,9 +841,9 @@ class DeliciousAPI(object):
                 url_tags = []
                 tagdisplays = bookmark_element.findAll("div", attrs={"class": "tagdisplay"})
                 if tagdisplays:
-                    spans = tagdisplays[0].findAll("span", attrs={"class": "tagItem"})
-                    for span in spans:
-                        tag = span.contents[0]
+                    aset = tagdisplays[0].findAll("a", attrs={"class": "tagItem noplay"})
+                    for a in aset:
+                        tag = a.contents[0]
                         url_tags.append(tag)
 
                 bookmarks.append( (url, url_tags, title, comment, timestamp) )
